pico-8 cartridge // http://www.pico-8.com
version 38
__lua__
-- snowy drive by zykino
-- ludum dare 51: every 10 seconds
-- alt name: wipe on cooldown

function secs_10()
	local s = flr(t()) - secs
	if (s % 10 == 0) then
		if (not theme) then
			score += 10

			theme = true
			return true
		end

		return false
	end
	theme = false
	return false
end

function start()
	score = 0
	theme = false
	theme_frame = false
	game_over = false
	player = {
		x = 56, -- not centred but but same place as the title screen: (128/2) - 4,
		y = 120,
	}
	spawn_rate = {
		obstacle = 20,
		snowflake = 2,
	}
	obstacles = {}
	snowflakes = {}
	wiper = {
		x = 130,
		y = 0,
		active = false,
		height = 128,
	}

	secs = flr(t()) % 10
end

function _init()
	screen = {
		⬆️ = 0,
		⬇️ = 128 + 8, -- screen bottom + sprite size
		⬅️ = 0,
		➡️ = 128 - 8, -- screen right - sprite size
	}
	high_score = 0

	start()
	game_over = true
end

function _update()
	if game_over then
		title_screen()
		return
	end

	theme_frame = secs_10()
	apply_inputs()
	update_obstacles()
	update_snowflakes()
	update_wiper()

	spawn_obstacle()
	spawn_snowflake()
	if (theme_frame) activate_wiper()

	check_collision_table(player, obstacles, function ()
		game_over = true
		if (high_score < score) high_score = score
		sfx(1)
	end)

	check_collision_table(wiper, snowflakes, function (e)
		del(snowflakes, e)
	end)
end

function _draw()
	--cls() -- replaced by the wiper: theme!!!
--if (theme) cls() -- debug

	if game_over then
		draw_go()
		return
	end

	foreach(obstacles, draw_sprite)
	foreach(snowflakes, draw_sprite)

	draw_wiper()

	spr(1, player.x, player.y)

	draw_score({x=0,y=0})
end

function draw_go()
	cls()

	-- draw the entire map
	camera(0,0)
	map(0,0,0,0,128,32)

	local pt = {x=40,y=24}
	print("\#0press 🅾️, ❎, ⬆️ or ⬇️ to start", 2.5, pt.y - 6)
	draw_score(pt)
end

function draw_score(pos)
	color(9)

	print("\#0high score: "..high_score, pos.x, pos.y)
	print("\#0score: "..score, pos.x, pos.y + 6)
end

function draw_sprite(elem)
	spr(elem.sprite, elem.x, elem.y)
end

function draw_wiper()
	rectfill(wiper.x, 0, wiper.x + 16, screen.⬇️, 0)
	sspr(112, 0, 8, 8, wiper.x, 0, 8, 60)
	sspr(112, 8, 8, 8, wiper.x, 60, 8, 8)
	sspr(112, 16, 8, 8, wiper.x, 68, 8, 60)	
end
-->8
-- controls

function apply_inputs()
	-- todo: up/down or are we fixed at the bottom?
	if (btn(⬅️)) player.x -= 1
	if (btn(➡️)) player.x += 1

	if (player.x < screen.⬅️) player.x = screen.⬅️
	if (screen.➡️ < player.x) player.x = screen.➡️
end

-->8
-- snowflake

function update_snowflakes()
	--foreach(snowflakes, advance)
end

function spawn_snowflake()
	if (flr(rnd(spawn_rate.snowflake)) == 0) then
		local s = {
			x = rnd(screen.➡️),
			y = rnd(screen.⬇️ - 16),
			sprite = flr(rnd(7)) + 16,
		}

		add(snowflakes, s)
	end
end

function update_wiper()
	if (not wiper.active) return

	wiper.x -= 8

	if (wiper.x < -20) then
		wiper.x = 130
		wiper.active = false
	end
end

function activate_wiper()
	wiper.active = true
	sfx(0)
end
-->8
-- obstacles

function update_obstacles()
	for e in all(obstacles) do
		e.y += 1
		if (screen.⬇️ < e.y) then
			del (obstacles, e)
			score += 1
		end
	end
end

function spawn_obstacle()
	if (flr(rnd(spawn_rate.obstacle)) == 0) then
		local o = {
			x = rnd(screen.➡️),
			y = 0,
			sprite = flr(rnd(2)) + 2,
		}
		
		add(obstacles, o)
	end
end
-->8
-- util

function advance(elem)
	elem.y += 1
end

function check_collision_table(elem, table, cb)
	foreach(table, function(e)
		if (check_collision_elemts(elem,e)) cb(e)
	end)
end

function check_collision_elemts(a,b)
 local height = a.height or 8

	return not (a.x > b.x + 8
		or a.y > b.y + height
		or a.x + 8 < b.x
		or a.y + height < b.y)
end
-->8
-- title & game over screen

function title_screen()
	if btnp(🅾️)
		or btnp(❎)
		or btnp(⬆️)
		or btnp(⬇️)
		then
		game_over = false
		start()
	end
end
__gfx__
000000000ad22da0007730000077750000000000000000000000000000000000000000000000000000000000000000000000000000000000d7771d0000000000
000000000d2222d0077777300ccc750000000000000000000000000000000000000000000000000000000000000000000000000000000000d7771d0000000000
007007001d2cc2d10377bbb37cc6657700000000000000000000000000000000000000000000000000000000000000000000000000000000d7711d0000000000
000770000c2dd2c0033bb3337765555700000000000000000000000000000000000000000000000000000000000000000000000000000000d7111d0000000000
000770000c2dd2c0333333335677755500000000000000000000000000000000000000000000000000000000000000000000000000000000d7771d0000000000
007007001d2cc2d10333bb305776665500000000000000000000000000000000000000000000000000000000000000000000000000000000d7771d0000000000
000000000d2222d0003444005665555000000000000000000000000000000000000000000000000000000000000000000000000000000000d7771d0000000000
0000000008d22d80044455400655555000000000000000000000000000000000000000000000000000000000000000000000000000000000d7711d0000000000
70c00c0770c00c07770000770700007000007000000000000000000000000000000000000000000000000000000000000000000000000000d7711d0000000000
070000700c0000c07c7007c77c7007c700077700000c00000000000000000000000000000000000000000000000000000000000000000000d7711d0000000000
c07cc70cc0c77c0c07c0cc7007c0cc700070707000ccc0000000000000000000000000000000000000000000000000000000000000000000d7221d0000000000
00c77c00007cc70000c7700000c77000077777770c0c0c000000000000000000000000000000000000000000000000000000000000000000d7551d0000000000
00c77c00007cc70000077c0000077c0000707070ccccccc00000000000000000000000000000000000000000000000000000000000000000d7251d0000000000
c07cc70cc0c77c0c07cc0c7007cc0c70000777000c0c0c000000000000000000000000000000000000000000000000000000000000000000d7251d0000000000
070000700c0000c07c7007c77c7007c70000700000ccc0000000000000000000000000000000000000000000000000000000000000000000d7751d0000000000
70c00c0770c00c07770000770700007000000000000c00000000000000000000000000000000000000000000000000000000000000000000d7751d0000000000
0000000099990000009999000000000000000000000000009999990099999990999999990000000099999999000000000000000000000000d7151d0000000000
0099999999999900099999909000000990000009000000009909999099000099999999999000000999999999000000000000000000000000d7151d0000000000
0999999099999900999009999000000999900099000000009900099999000099000990009900009999000000000000000000000000000000d7751d0000000000
0990000099009990990000999909909909999999009999009900009999999990000990009990099999999000000000000000000000000000d7771d0000000000
0999999099000990990000999909909900099990009999009900009999999900000990000990099099999000000000000000000000000000d7771d0000000000
0000099099000999999009999999999900099900000000009900099999009990000990000099990099000000000000000000000000000000d7151d0000000000
9999999099000099099999900990099000999000000000009909999099000999999999990099990099999999000000000000000000000000d7151d0000000000
0999990099000009009999000090090000990000000000009999990099000099999999990009900099999999000000000000000000000000d7751d0000000000
__label__
00000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000
0000000070c00c0700000000000000000000700000000000000000000000000000000000000000000000000070c00c0700000000070000700000000000773000
00000000070000700000000000000000000777000000000000000000000000000000000000000000000000000c0000c0000000007c7007c70000000007777730
00000000c07cc70c000000000000000000707070000000000000000000000000000000000000000000000000c0c77c0c0000000007c0cc70000000000377bbb3
0000000000c77c00000000000000000007777777000000000000000000000000000000000000000000000000007cc7000000000000c7700000000000033bb333
0000000000c77c00000000000000000000707070000000000000000000000000000000000000000000000000007cc7000000000000077c000000000033333333
00000000c07cc70c000000000000000000077700000000000000000000000000000000000000000000000000c0c77c0c0000000007cc0c70000000000333bb30
00000000070000700000000000000000000070000000000000000000000000000000000000000000000000000c0000c0000000007c7007c70000000000344400
0000000070c00c0700000000000000000000000000000000000000000000000000000000000000000000000070c00c0700000000070000700000000004445540
00000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000
00999099909990099009900000099999000000000009999900000000000999990000000990999000000999990000009990099000000990999099909990999000
00909090909000900090000000990009900000000099090990000000009990999000009090909000009900099000000900909000009000090090909090090000
00999099009900999099900000990909900000000099909990000000009900099000009090990000009900099000000900909000009990090099909900090000
00900090909000009000900000990009900900000099090990090000009900099000009090909000009990999000000900909000000090090090909090090000
00900090909990990099000000099999009000000009999900900000000999990000009900909000000999990000000900990000009900090090909090090000
00000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000077000077000000009090999009909090000009900990099099909990000000009990999090900c07000000000000000000000000
0000000000000000000000007c7007c7000000009090090090009090000090009000909090909000090000009000009090900070000000000000000000000000
00000000000000000000000007c0cc7000000000999009009000999000009990900090909900990000000000999099909990c70c000000000000000000000000
00000000000000000000000000c77000000000009090090090909090000000909000909090909000090000000090900000907c00000000000000000000000000
00000000000000000000000000077c00000000009090999099909090000099000990990090909990000000009990999000907c00000000000000000000000000
00000000000000000000000007cc0c7000000000000000000000000000000000000000000000000000000000000000000000c70c000000000000000000000000
0000000000000000000000007c7007c7000000000990099009909990999000000000999099909090000000000000000007000070000000000000000000000000
00000000000000000000000077000077000000009000900090909090900009000000900000909090000000000000000070c00c07000000000000000000000000
00000000000000000000000000000000000000009990900090909900990000000000999099909990000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000090900090909090900009000000009090000090000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000009900099099009090999000000000999099900090000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000
007775000000000070c00c0700000000000000000000000000000000000000000000000000000000000000000000000000000000000000000077300000000000
0ccc7500000000000c0000c0000000000000000000000000000000000000000000000000000000000000000000000000000c0000000000000777773000000000
7cc6657700000000c0c77c0c00000000000000000000000000000000000000000000000000000000000000000000000000ccc000000000000377bbb300000000
7765555700000000007cc7000000000000000000000000000000000000000000000000000000000000000000000000000c0c0c0000000000033bb33300000000
5677755500000000007cc700000000000000000000000000000000000000000000000000000000000000000000000000ccccccc0000000003333333300000000
5776665500000000c0c77c0c0000000000000000000000000000000000000000000000000000000000000000000000000c0c0c00000000000333bb3000000000
56655550000000000c0000c000000000000000000000000000000000000000000000000000000000000000000000000000ccc000000000000034440000000000
065555500000000070c00c07000000000000000000000000000000000000000000000000000000000000000000000000000c0000000000000444554000000000
07000070000000000000000000000000000000000000000000000000000000000000000000000000770000770000000000000000000000000000000000000000
7c7007c70000000000000000000000000000000000000000000000000000000000000000000000007c7007c70000000000000000000000000000000000000000
07c0cc7000000000000000000000000000000000000000000000000000000000000000000000000007c0cc700000000000000000000000000000000000000000
00c7700000000000000000000000000000000000000000000000000000000000000000000000000000c770000000000000000000000000000000000000000000
00077c0000000000000000000000000000000000000000000000000000000000000000000000000000077c000000000000000000000000000000000000000000
07cc0c7000000000000000000000000000000000000000000000000000000000000000000000000007cc0c700000000000000000000000000000000000000000
7c7007c70000000000000000000000000000000000000000000000000000000000000000000000007c7007c70000000000000000000000000000000000000000
07000070000000000000000000000000000000000000000000000000000000000000000000000000770000770000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000000000000070c00c070000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000c0000c00000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000c0c77c0c0000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000007cc7000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000007cc7000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000c0c77c0c0000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000c0000c00000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000000000000070c00c070000000000000000000000000000000000000000000000000000000000000000
00000000007730000000000000000000000000000000000000000000000000000000000000773000000000000000000070c00c07007730000000000000777500
0000000007777730000000000000000000000000000000000000000000000000000000000777773000000000000000000c0000c007777730000000000ccc7500
000000000377bbb3000000000000000000000000000000000000000000000000000000000377bbb30000000000000000c0c77c0c0377bbb3000000007cc66577
00000000033bb33300000000000000000000000000000000000000000000000000000000033bb3330000000000000000007cc700033bb3330000000077655557
000000003333333300000000000000000000000000000000000000000000000000000000333333330000000000000000007cc700333333330000000056777555
000000000333bb30000000000000000000000000000000000000000000000000000000000333bb300000000000000000c0c77c0c0333bb300000000057766655
0000000000344400000000000000000000000000000000000000000000000000000000000034440000000000000000000c0000c0003444000000000056655550
00000000044455400000000000000000000000000000000000000000000000000000000004445540000000000000000070c00c07044455400000000006555550
00000000000000000077750000777500000000000000000000000000000000000000000000000000007730000000000000000000000000000077300000000000
00000000000000000ccc75000ccc7500000000000000000000000000000000000000000000000000077777300000000000000000000000000777773000000000
00000000000000007cc665777cc665770000000000000000000000000000000000000000000000000377bbb30000000000000000000000000377bbb300000000
00000000000000007765555777655557000000000000000000000000000000000000000000000000033bb333000000000000000000000000033bb33300000000
00000000000000005677755556777555000000000000000000000000000000000000000000000000333333330000000000000000000000003333333300000000
000000000000000057766655577666550000000000000000000000000000000000000000000000000333bb300000000000000000000000000333bb3000000000
00000000000000005665555056655550000000000000000000000000000000000000000000000000003444000000000000000000000000000034440000000000
00000000000000000655555006555550000000000000000000000000000000000000000000000000044455400000000000000000000000000444554000000000
00777500000000000000000000000000000000000000000070c00c07000000000000000000773000000000000077300000773000000000000000000000000000
0ccc7500000000000000000000000000000000000000000007000070000000000000000007777730000000000777773007777730000000000000000000000000
7cc665770000000000000000000000000000000000000000c07cc70c00000000000000000377bbb3000000000377bbb30377bbb3000000000000000000000000
77655557000000000000000000000000000000000000000000c77c000000000000000000033bb33300000000033bb333033bb333000000000000000000000000
56777555000000000000000000000000000000000000000000c77c00000000000000000033333333000000003333333333333333000000000000000000000000
577666550000000000000000000000000000000000000000c07cc70c00000000000000000333bb30000000000333bb300333bb30000000000000000000000000
56655550000000000000000000000000000000000000000007000070000000000000000000344400000000000034440000344400000000000000000000000000
06555550000000000000000000000000000000000000000070c00c07000000000000000004445540000000000444554004445540000000000000000000000000
00000000000000000077300000777500000000000000000000000000000000000000000000000000000000000077750000777500007730000000000000773000
0000000000000000077777300ccc7500000000000000000000000000000000000000000000000000000000000ccc75000ccc7500077777300000000007777730
00000000000000000377bbb37cc66577000000000000000000000000000000000000000000000000000000007cc665777cc665770377bbb3000000000377bbb3
0000000000000000033bb33377655557000000000000000000000000000000000000000000000000000000007765555777655557033bb33300000000033bb333
00000000000000003333333356777555000000000000000000000000000000000000000000000000000000005677755556777555333333330000000033333333
00000000000000000333bb30577666550000000000000000000000000000000000000000000000000000000057766655577666550333bb30000000000333bb30
00000000000000000034440056655550000000000000000000000000000000000000000000000000000000005665555056655550003444000000000000344400
00000000000000000444554006555550000000000000000000000000000000000000000000000000000000000655555006555550044455400000000004445540
00000000007775000000000000000000000000000000000000000000070000700000000000773000000000000077300000000000000000007700007700000000
000000000ccc750000000000000000000000000000000000000000007c7007c70000000007777730000000000777773000000000000000007c7007c700000000
000000007cc66577000000000000000000000000000000000000000007c0cc70000000000377bbb3000000000377bbb3000000000000000007c0cc7000000000
0000000077655557000000000000000000000000000000000000000000c7700000000000033bb33300000000033bb333000000000000000000c7700000000000
0000000056777555000000000000000000000000000000000000000000077c0000000000333333330000000033333333000000000000000000077c0000000000
0000000057766655000000000000000000000000000000000000000007cc0c70000000000333bb30000000000333bb30000000000000000007cc0c7000000000
000000005665555000000000000000000000000000000000000000007c7007c70000000000344400000000000034440000000000000000007c7007c700000000
00000000065555500000000000000000000000000000000000000000070000700000000004445540000000000444554000000000000000007700007700000000
07000070000000000000700000000000007775000000000000000000000000000000000000000000007730000000000000773000000000000077300000000000
7c7007c70000000000077700000000000ccc75000000000000000000000000000000000000000000077777300000000007777730000000000777773000000000
07c0cc700000000000707070000000007cc6657700000000000000000000000000000000000000000377bbb3000000000377bbb3000000000377bbb300000000
00c77000000000000777777700000000776555570000000000000000000000000000000000000000033bb33300000000033bb33300000000033bb33300000000
00077c00000000000070707000000000567775550000000000000000000000000000000000000000333333330000000033333333000000003333333300000000
07cc0c700000000000077700000000005776665500000000000000000000000000000000000000000333bb30000000000333bb30000000000333bb3000000000
7c7007c7000000000000700000000000566555500000000000000000000000000000000000000000003444000000000000344400000000000034440000000000
07000070000000000000000000000000065555500000000000000000000000000000000000000000044455400000000004445540000000000444554000000000
00777500000000000077750000000000000000000000000000000000000000000000000000773000007730000077300000000000007775000000000000000000
0ccc7500000000000ccc7500000000000000000000000000000000000000000000000000077777300777773007777730000000000ccc75000000000000000000
7cc66577000000007cc665770000000000000000000000000000000000000000000000000377bbb30377bbb30377bbb3000000007cc665770000000000000000
776555570000000077655557000000000000000000000000000000000000000000000000033bb333033bb333033bb33300000000776555570000000000000000
56777555000000005677755500000000000000000000000000000000000000000000000033333333333333333333333300000000567775550000000000000000
5776665500000000577666550000000000000000000000000000000000000000000000000333bb300333bb300333bb3000000000577666550000000000000000
56655550000000005665555000000000000000000000000000000000000000000000000000344400003444000034440000000000566555500000000000000000
06555550000000000655555000000000000000000000000000000000000000000000000004445540044455400444554000000000065555500000000000000000
000000000000000000000000007775000000000000000000000000000ad22da00000000000000000000000000077300000000000000000000077300000000000
0000000000000000000000000ccc75000000000000000000000000000d2222d00000000000000000000000000777773000000000000000000777773000000000
0000000000000000000000007cc665770000000000000000000000001d2cc2d10000000000000000000000000377bbb300000000000000000377bbb300000000
000000000000000000000000776555570000000000000000000000000c2dd2c0000000000000000000000000033bb3330000000000000000033bb33300000000
000000000000000000000000567775550000000000000000000000000c2dd2c00000000000000000000000003333333300000000000000003333333300000000
000000000000000000000000577666550000000000000000000000001d2cc2d10000000000000000000000000333bb3000000000000000000333bb3000000000
000000000000000000000000566555500000000000000000000000000d2222d00000000000000000000000000034440000000000000000000034440000000000
0000000000000000000000000655555000000000000000000000000008d22d800000000000000000000000000444554000000000000000000444554000000000

__map__
0000202122232425262728292a00000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000
0010000014000000000000110013000200000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000
0000001200000000000000001000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000
0300110000000000000000001500020000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000
1300000000000000000012000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000011000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000
0002000000000000000200001102000300000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000
0000030300000000000002000000020000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000
0300000000001000000200020200000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000
0000020300000000000000030302000200000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000
0003000000000013000200020000120000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000
1300140003000000000002000200020000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000
0300030000000000000202020003000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000
0000000300000001000000020000020000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000
__sfx__
000400001e6201a620176201562013620116200f6200e6200d6200d6200e620106201162015620176200060000600006000060000600006000060000600006000060000600006000060000600006000060000600
000300002b650236501b65017650116300f6301632016320173201431014310196000060000600006000060000600006000060000600006000060000600006000060000600006000060000600006000060000600
